@@ -39,7 +39,7 @@ use Net::SolarWinds::Log;
 use JSON qw();
 use URI::Encode qw(uri_encode);
 
-our $VERSION=1.12;
+our $VERSION=1.13;
 
 use base qw(Net::SolarWinds::ConstructorHash Net::SolarWinds::LogMethods Net::SolarWinds::Helper);
 use constant RESULT_CLASS=>'Net::SolarWinds::Result';
@@ -221,8 +221,10 @@ sub DiscoverInterfacesOnNode {
   # force a string;
   $nodeId .='';
 
+  $self->log_info("Started Discoverying interfaces on nodeid: $nodeId");
   my $request=$self->build_request('POST','Invoke/Orion.NPM.Interfaces/DiscoverInterfacesOnNode',[$nodeId]);
   my $result=$self->run_request($request);
+  $self->log_info("Finished Discoverying interfaces on nodeid: $nodeId");
 
   return $result;
 }
