@@ -265,7 +265,7 @@ sub set_managed {
   my $node=$result->get_data;
   my $node_id=$node->{NodeID};
 
-  return $self->UpdateNodeProps($node_id,UnManaged=>$state);
+  return $self->UpdateNodeProps($node_id,UnManaged=>JSON::true);
 }
 
 =item * my $result=$self->get_management_config($thing);
@@ -418,10 +418,15 @@ Returns a Net::SolarWinds::Result object, when true it contains a hash mapping i
 
 sub getPollerInterfaceMap {
   my ($self,$nodeid)=@_;
+
+  $self->log_info("Starting poller type lookup of nodeid: $nodeid");
   my $query=$self->query_lookup($nodeid);
 
   my $result=$self->Query($query);
-  return $result unless $result;
+  unless($result) {
+    $self->log_error("Finished poller type lookup of nodeid: $nodeid error was: $result");
+    return $result;
+  }
 
   my $hash={};
   my $list=$result->get_data->{results};
@@ -432,6 +437,7 @@ sub getPollerInterfaceMap {
     push @{$hash->{$id}},$poller->{PollerType};
   }
 
+  $self->log_info("Finished poller type lookup of nodeid: $nodeid");
   return $self->RESULT_CLASS->new_true($hash);
 }
 
@@ -916,6 +922,25 @@ sub build_node {
 
 }
 
+=item * my $result=$self->build_unmanaged($ip,$DeleteIfExists,%args);
+
+Wrapper for build_node, flips the node to UnManaged=>1 once it has been created or if it all ready exists.
+
+=cut
+
+sub build_unmanaged {
+  my ($self,$ip,$DeleteIfExists,%args)=@_;
+  my $result=$self->build_node($ip,$DeleteIfExists,%args);
+  return $result unless $result;
+
+  my $nodeID=$result->get_data->{NodeID};
+  my $target=$result;
+  $result=$self->UpdateNodeProps($nodeID,"UnManaged"=>JSON::true);
+  return $result unless $result;
+
+  return $target;
+}
+
 =back
 
 =head1 AUTHOR
